@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 17's 3.9 kernel.
+# This is a kernel build script for Fedora 19's 3.12 kernel.
 #
 
 die () {
@@ -8,21 +8,21 @@ die () {
     exit 1
 }
 
-yum -y install wget rpm-build make gcc patch redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc bison net-tools audit-libs-devel bc
+yum -y install tar wget rpm-build make gcc patch redhat-rpm-config xmlto asciidoc gnupg elfutils-devel zlib-devel binutils-devel newt-devel python-devel perl-ExtUtils-Embed pciutils-devel hmaccalc bison net-tools audit-libs-devel pesign bc
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-3.9.10-100.fc17.src.rpm ]
+if [ ! -r kernel-3.12.11-201.fc19.src.rpm ]
 then
-    wget http://archives.fedoraproject.org/pub/archive/fedora/linux/updates/17/SRPMS/kernel-3.9.10-100.fc17.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/19/SRPMS/kernel-3.12.11-201.fc19.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-3.9.10-100.fc17.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-3.9.10-100.fc17.src.rpm || die "Can't install source package."
+rpm --checksig kernel-3.12.11-201.fc19.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-3.12.11-201.fc19.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20131201.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20140222.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20131201.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20131201.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20140222.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20140222.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -30,7 +30,7 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -23,7 +23,7 @@
+@@ -31,7 +31,7 @@
  #
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
@@ -39,7 +39,7 @@ patch << "EOF" || die "Can't patch spec file."
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -433,6 +433,11 @@
+@@ -428,6 +428,11 @@
  # to versions below the minimum
  #
  
@@ -51,16 +51,16 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -492,7 +497,7 @@
+@@ -490,7 +495,7 @@
  AutoProv: yes\
  %{nil}
  
 -Name: kernel%{?variant}
 +Name: ccs-kernel%{?variant}
  Group: System Environment/Kernel
- License: GPLv2
+ License: GPLv2 and Redistributable, no modification permitted
  URL: http://www.kernel.org/
-@@ -969,7 +974,7 @@
+@@ -971,7 +976,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -69,8 +69,8 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -989,7 +994,7 @@
- Provides: kernel-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
+@@ -991,7 +996,7 @@
+ Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:.%{1}}\
  Requires: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
 -%description -n kernel%{?variant}%{?1:-%{1}}-modules-extra\
@@ -78,18 +78,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
  %{nil}
  
-@@ -1518,6 +1523,10 @@
+@@ -1510,6 +1515,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20131201.tar.gz
-+patch -sp1 < patches/ccs-patch-3.9-fedora-17.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20140222.tar.gz
++patch -sp1 < patches/ccs-patch-3.12-fedora-19.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1547,6 +1556,18 @@
+@@ -1532,6 +1541,18 @@
  for i in *.config
  do
    mv $i .config
