@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.3+   2012/04/01
+ * Version: 1.8.3+   2012/05/05
  */
 
 #include "internal.h"
@@ -224,8 +224,9 @@ static int __ccs_alloc_task_security(const struct task_struct *task)
 		[hash_ptr((void *) task, CCS_TASK_SECURITY_HASH_BITS)];
 	if (!new_security)
 		return -ENOMEM;
-	*new_security = *old_security;
 	new_security->task = task;
+	new_security->ccs_domain_info = old_security->ccs_domain_info;
+	new_security->ccs_flags = old_security->ccs_flags;
 	ccs_add_task_security(new_security, list);
 	return 0;
 }
